@@ -9,7 +9,9 @@ from fa_purity.frozen import (
 )
 from fa_purity.result import (
     Result,
-    UnwrapError,
+)
+from fa_purity.result.transform import (
+    all_ok,
 )
 from typing import (
     TypeVar,
@@ -28,7 +30,5 @@ def flatten_cmds(items: FrozenList[Cmd[_T]]) -> Cmd[FrozenList[_T]]:
 def flatten_results(
     items: FrozenList[Result[_S, _F]]
 ) -> Result[FrozenList[_S], _F]:
-    try:
-        return Result.success(tuple(i.unwrap() for i in items))
-    except UnwrapError[_S, _F] as err:
-        return Result.failure(err.container.unwrap_fail())
+    """all_ok function alias"""
+    return all_ok(items)
