@@ -70,6 +70,9 @@ class Unfolder:
     def get(self, key: str) -> ResultE[JsonValue]:
         return self.to_json().alt(Exception).bind(lambda d: try_get(d, key))
 
+    def uget(self, key: str) -> ResultE[Unfolder]:
+        return self.get(key).map(lambda j: Unfolder(j))
+
     def to_primitive(
         self, prim_type: Type[NotNonePrimTvar]
     ) -> Result[NotNonePrimTvar, InvalidType]:
