@@ -1,3 +1,6 @@
+from ._inner import (
+    InnerStream,
+)
 from fa_purity import (
     _iter_factory,
 )
@@ -8,7 +11,6 @@ from fa_purity.pure_iter.core import (
     PureIter,
 )
 from fa_purity.stream.core import (
-    _Stream,
     Stream,
 )
 from typing import (
@@ -28,9 +30,9 @@ def unsafe_from_cmd(cmd: Cmd[Iterable[_T]]) -> Stream[_T]:
     # As with `PureIter unsafe_from_cmd` the cmd must return a new iterable
     # object in each call to ensure that the stream is never consumed,
     # nevertheless they can be semanticly different iterables.
-    return Stream(_Stream(cmd))
+    return Stream(InnerStream(cmd))
 
 
 def from_piter(piter: PureIter[Cmd[_T]]) -> Stream[_T]:
-    draft = _Stream(Cmd.from_cmd(lambda: _iter_factory.squash(piter)))
-    return Stream(draft)
+    items = InnerStream(_iter_factory.squash(piter))
+    return Stream(items)
